@@ -26,7 +26,10 @@ class ImageWidget : public QPushButton
     Q_OBJECT
 
 public:
-    enum Type { Photo, Logo };
+    enum Type {
+        Photo,
+        Logo
+    };
 
     explicit ImageWidget(Type type, QWidget *parent = nullptr);
     ~ImageWidget() override;
